@@ -1,5 +1,5 @@
 /* C-SKY disassembler.
-   Copyright (C) 1988-2022 Free Software Foundation, Inc.
+   Copyright (C) 1988-2025 Free Software Foundation, Inc.
    Contributed by C-SKY Microsystems and Mentor Graphics.
 
    This file is part of the GNU opcodes library.
@@ -49,7 +49,7 @@ struct csky_dis_info
   disassemble_info *info;
   /* Opcode information.  */
   struct csky_opcode_info const *opinfo;
-  BFD_HOST_U_64_BIT isa;
+  uint64_t isa;
   /* The value of operand to show.  */
   int value;
   /* Whether to look up/print a symbol name.  */
@@ -239,7 +239,7 @@ csky_get_disassembler (bfd *abfd)
 {
   obj_attribute *attr;
   const char *sec_name = NULL;
-  if (!abfd)
+  if (!abfd || bfd_get_flavour (abfd) != bfd_target_elf_flavour)
     dis_info.isa = CSKY_DEFAULT_ISA;
   else
     {
@@ -519,7 +519,7 @@ csky_output_operand (char *str, struct operand const *oprnd,
     case OPRND_TYPE_FCONSTANT:
       {
 	int shift = oprnd->shift;
-	char ibytes[8];
+	bfd_byte ibytes[8];
 	int status;
 	bfd_vma addr;
 	int nbytes;
@@ -538,19 +538,13 @@ csky_output_operand (char *str, struct operand const *oprnd,
 	else
 	  nbytes = 4;
 
-	status = dis_info.info->read_memory_func (addr, (bfd_byte *)ibytes,
+	status = dis_info.info->read_memory_func (addr, ibytes,
 						  nbytes, dis_info.info);
 	if (status != 0)
 	  /* Address out of bounds.  -> lrw rx, [pc, 0ffset]. */
 	  sprintf (buf, "[pc, %d]\t// from address pool at %x", (int)value,
 		   (unsigned int)addr);
-	else
-	  {
-	    dis_info.value = addr;
-	    value = csky_chars_to_number ((unsigned char *)ibytes, 4);
-	  }
-
-	if (oprnd->type == OPRND_TYPE_FCONSTANT)
+	else if (oprnd->type == OPRND_TYPE_FCONSTANT)
 	  {
 	    double f;
 
@@ -569,8 +563,10 @@ csky_output_operand (char *str, struct operand const *oprnd,
 	  }
 	else
 	  {
+	    dis_info.value = addr;
 	    dis_info.need_output_symbol = 1;
-	    sprintf (buf, "0x%x", (unsigned int)value);
+	    value = csky_chars_to_number (ibytes, 4);
+	    sprintf (buf, "0x%x", (unsigned int) value);
 	  }
 
 	strcat (str, buf);
